#ifndef INCLUSIONWIZARD_H
#define INCLUSIONWIZARD_H

#include <kwizard.h>
#include <klistviewsearchline.h>
#include <klistview.h>

#include <qvbox.h>

class InclusionPage;
class KListViewSearchLine;
class KListView;

class QListViewItem;

class InclusionWizard : public KWizard
{
  friend class InclusionPage;

public:
  InclusionWizard(QWidget* parent = 0, bool modal = false);
  void addConflict(const QString& type, const QStringList& locals, 
		   const QStringList& globals);
  QStringList getLocalResolvedIncludes() const;
  QStringList getGlobalResolvedIncludes() const;
};

class InclusionSearchLine : public KListViewSearchLine
{
  Q_OBJECT

public:
  InclusionSearchLine(QWidget *parent, const char *name);

public slots:
  void updateSearch(const QString& s = QString::null);

protected:
  void keyPressEvent(QKeyEvent*);

signals:
  void updatedSearch();
};

class InclusionPage : public QVBox
{
  Q_OBJECT

public:
  InclusionPage(InclusionWizard* parent, const QString& type, 
		const QStringList& locals, const QStringList& globals);
  QString getResolved() const;
  bool isLocal() const;

protected:
  void showEvent(QShowEvent*);

private slots:
  void verifyInput();
  void executed(); 
  void selectionChanged(QListViewItem* item);

private:
  InclusionWizard* wizard;
  InclusionSearchLine* search;
  KListView* listView;
  bool local;
  QString file;

  int visibleItemsCount();
  bool setNextOrFinished(bool enable);
};

class HeaderItem : public KListViewItem
{
public:
  HeaderItem(QListView* parent, const QString& file, bool local);
  const QString& getFile() const;
  bool isLocal() const;

private:
  QString file;
  bool local;
};

class HeaderItemListView : public KListView
{
public:
  HeaderItemListView(QWidget* parent);

protected:
  void keyPressEvent(QKeyEvent* event);
};

#endif
